@@ -1,5 +1,9 @@
+from typing import Any, Dict
 from django.conf import settings
-from ...conf import DOMAIN
+
+from mqueue.models import MEvent
+
+# from ...conf import DOMAIN
 try:
     from instant.conf import SITE_SLUG
     from instant.producers import publish
@@ -7,13 +11,13 @@ except ImportError:
     pass
 
 
-def save(event, conf):
-    data = {}
+def save(event: MEvent, conf: Dict[str, Any]):
+    data: Dict[str, Any] = {}
     if event.data:
-        data = event.data
+        data["data"] = event.data
     user = "anonymous"
     if event.user:
-        user = event.user.username
+        user = event.user.username  # type: ignore
     url = ""
     if event.url:
         url = event.url
@@ -26,18 +30,19 @@ def save(event, conf):
     data["user"] = user
     data["url"] = url
     data["admin_url"] = admin_url
-    data["bucket"] = bucket
     site = SITE_SLUG
-    if "site" in event.data:
-        site = event.data["site"]
-    err = publish(
-        conf["channel"],
-        event.name,
-        event_class=event.event_class,
-        data=data,
-        site=site,
-    )
-    if err is not None:
+    if "site" in event.data:  # type: ignore
+        site = event.data["site"]  # type: ignore
+    try:
+        publish(
+            conf["channel"],
+            event.name,
+            event_class=event.event_class,
+            data=data,
+            bucket=bucket,
+            site=site,
+        )
+    except Exception as err:
         if settings.DEBUG:
             print("Error in Centrifugo mqueue hook:", err)
         raise Exception(err)
